@@ -2,7 +2,7 @@
 from predictions_analyzer.tabular import *
 from sklearn.metrics import accuracy_score
 
-classification_data_path = "tests/test_datasets/classification/"
+classification_data_path = "./test_datasets/classification/"
 
 def get_ExClfObj():
     ex = ClassificationAnalyzer(simulate_data=True)
@@ -156,6 +156,28 @@ def test_mode_ensemble():
 
     # Assert there is only one mean column!
 
+def test_show_confusion_matrix():
+    ex = get_ExClfObj()
+    titanic = get_titanic_obj()
+
+    test_objects = [("simulated", ex), ("titanic", titanic)]
+
+    for name, obj in test_objects:
+        print("\nTesting: ", name, " dataset")
+
+        obj.show_confusion_matrix()
+
+def test_show_classification_report():
+    ex = get_ExClfObj()
+    titanic = get_titanic_obj()
+
+    test_objects = [("simulated", ex), ("titanic", titanic)]
+
+    for name, obj in test_objects:
+        print("\nTesting: ", name, " dataset")
+
+        obj.show_classification_report()
+
 def test_all_stat_ensembled_pred_metrics():
     ex = get_ExClfObj()
     titanic = get_titanic_obj()
@@ -220,3 +242,12 @@ def test_find_hardest_samples():
         # Assert all values in self.trues_df?
 
 
+def test_show_all_reports():
+    ex = get_ExClfObj()
+    titanic = get_titanic_obj()
+
+    test_objects = [("simulated", ex), ("titanic", titanic)]
+
+    for name, obj in test_objects:
+        print("\nTesting: ", name, " dataset")
+        obj.show_all_reports()
\ No newline at end of file
